@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   WCSLIB 3.5 - an implementation of the FITS WCS convention.
+*   WCSLIB 3.6 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2004, Mark Calabretta
 *
 *   This program is free software; you can redistribute it and/or modify it
@@ -27,7 +27,7 @@
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
 *   http://www.atnf.csiro.au/~mcalabre/index.html
-*   $Id: tcel1.c,v 3.5 2004/06/28 01:02:17 mcalabre Exp $
+*   $Id: tcel1.c,v 3.6 2004/08/25 05:31:25 cal103 Exp $
 *=============================================================================
 *
 *   tcel1 tests the spherical projection driver routines supplied with WCSLIB
@@ -57,8 +57,8 @@ int main()
    printf("\nTesting WCSLIB celestial coordinate transformation routines\n");
    printf("-----------------------------------------------------------\n");
 
-   /* List error messages. */
-   printf("\nList of cel error codes:\n");
+   /* List status return messages. */
+   printf("\nList of cel status return values:\n");
    for (k = 1; k <= 6 ; k++) {
       printf("   %d: %s.\n", k, cel_errmsg[k]);
    }
