@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   WCSLIB 3.5 - an implementation of the FITS WCS convention.
+*   WCSLIB 3.6 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2004, Mark Calabretta
 *
 *   This program is free software; you can redistribute it and/or modify it
@@ -27,7 +27,7 @@
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
 *   http://www.atnf.csiro.au/~mcalabre/index.html
-*   $Id: tspc.c,v 3.5 2004/06/28 01:05:55 mcalabre Exp $
+*   $Id: tspc.c,v 3.6 2004/08/25 05:36:39 cal103 Exp $
 *=============================================================================
 *
 *   tspc tests the spectral transformation driver routines for closure.
@@ -42,11 +42,6 @@
 #include <wcstrig.h>
 #include <spc.h>
 
-#ifndef __STDC__
-#ifndef const
-#define const
-#endif
-#endif
 
 #define NSPEC 10001
 
@@ -79,8 +74,8 @@ int main()
    printf("\nTesting closure of WCSLIB spectral transformation routines\n");
    printf("----------------------------------------------------------\n");
 
-   /* List error messages. */
-   printf("\nList of spc error codes:\n");
+   /* List status return messages. */
+   printf("\nList of spc status return values:\n");
    for (j = 1; j <= 4 ; j++) {
       printf("   %d: %s.\n", j, spc_errmsg[j]);
    }
