@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   WCSLIB 3.5 - an implementation of the FITS WCS convention.
+*   WCSLIB 3.6 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2004, Mark Calabretta
 *
 *   This library is free software; you can redistribute it and/or modify it
@@ -27,7 +27,7 @@
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
 *   http://www.atnf.csiro.au/~mcalabre/index.html
-*   $Id: wcs.c,v 3.5 2004/06/28 04:03:12 mcalabre Exp $
+*   $Id: wcs.c,v 3.6 2004/08/25 05:18:22 cal103 Exp $
 *===========================================================================*/
 
 #include <math.h>
@@ -46,11 +46,11 @@ const int WCSSET = 137;
 int NPVMAX = 64;
 int NPSMAX =  8;
 
-/* Map error number to error message for each function. */
+/* Map status return value to message. */
 const char *wcs_errmsg[] = {
    0,
    "Null wcsprm pointer passed",
-   "Memory allocation error",
+   "Memory allocation failed",
    "Linear transformation matrix is singular",
    "Inconsistent or unrecognized coordinate axis types",
    "Invalid parameter value",
@@ -59,7 +59,9 @@ const char *wcs_errmsg[] = {
    "One or more of the pixel coordinates were invalid",
    "One or more of the world coordinates were invalid",
    "Invalid world coordinate",
-   "No solution found in the specified interval"};
+   "No solution found in the specified interval",
+   "Invalid subimage specification",
+   "Non-separable subimage coordinate system"};
 
 #define UNDEFINED 987654321.0e99
 #define undefined(value) (value == UNDEFINED)
@@ -269,6 +271,8 @@ struct wcsprm *wcs;
                  wcsfree(wcs);
                  return 2;
               }
+            } else {
+              wcs->pv = (struct pvcard *)0;
             }
 
             wcs->npvmax  = NPVMAX;
@@ -291,6 +295,8 @@ struct wcsprm *wcs;
                  wcsfree(wcs);
                  return 2;
               }
+            } else {
+              wcs->ps = (struct pscard *)0;
             }
 
             wcs->npsmax  = NPSMAX;
@@ -461,18 +467,18 @@ struct wcsprm *wcs;
       wcs->csyer[i] = UNDEFINED;
    }
    wcs->radesys[0] = '\0';
-   wcs->equinox = UNDEFINED;
+   wcs->equinox    = UNDEFINED;
    wcs->specsys[0] = '\0';
    wcs->ssysobs[0] = '\0';
-   wcs->velosys = UNDEFINED;
-   wcs->vsource = UNDEFINED;
-   wcs->zsource = UNDEFINED;
-   wcs->obsgeo[0] = UNDEFINED;
-   wcs->obsgeo[1] = UNDEFINED;
-   wcs->obsgeo[2] = UNDEFINED;
+   wcs->velosys    = UNDEFINED;
+   wcs->ssyssrc[0] = '\0';
+   wcs->zsource    = UNDEFINED;
+   wcs->obsgeo[0]  = UNDEFINED;
+   wcs->obsgeo[1]  = UNDEFINED;
+   wcs->obsgeo[2]  = UNDEFINED;
    wcs->dateobs[0] = '\0';
-   wcs->mjdobs = UNDEFINED;
-   wcs->mjdavg = UNDEFINED;
+   wcs->mjdobs     = UNDEFINED;
+   wcs->mjdavg     = UNDEFINED;
 
    /* Reset derived values. */
    strcpy(wcs->lngtyp, "    ");
@@ -490,14 +496,17 @@ struct wcsprm *wcs;
 
 /*--------------------------------------------------------------------------*/
 
-int wcscopy(alloc, wcssrc, wcsdst)
+int wcssub(alloc, wcssrc, nsub, axes, wcsdst)
 
 int alloc;
 const struct wcsprm *wcssrc;
+int *nsub, axes[];
 struct wcsprm *wcsdst;
 
 {
-   int i, j, k, naxis, npvmax, npsmax, status;
+   char *c, ctypei[16];
+   int  axis, cubeface, dealloc, dummy, i, j, k, latitude, longitude,
+        *map = 0, msub, naxis, npv, nps, other, spectral, status, stokes;
    const double *srcp;
    double *dstp;
 
@@ -507,49 +516,240 @@ struct wcsprm *wcsdst;
       return 2;
    }
 
-   /* Initialize the destination. */
-   npvmax = NPVMAX;
-   npsmax = NPSMAX;
-   NPVMAX = wcssrc->npvmax;
-   NPSMAX = wcssrc->npsmax;
-   if (status = wcsini(alloc, naxis, wcsdst)) {
-      return status;
+   if (!(map = (int *)calloc(naxis, sizeof(int)))) {
+      return 2;
    }
-   NPVMAX = npvmax;
-   NPSMAX = npsmax;
+
+   if (nsub == 0) {
+      nsub = &dummy;
+      *nsub = naxis;
+   } else if (*nsub == 0) {
+      *nsub = naxis;
+   }
+
+   if (dealloc = (axes == 0)) {
+      /* Construct an index array. */
+      if (!(axes = (int *)calloc(naxis, sizeof(int)))) {
+         return 2;
+      }
+
+      for (i = 0; i < naxis; i++) {
+         axes[i] = i+1;
+      }
+   }
+
+
+   msub = 0;
+   for (j = 0; j < *nsub; j++) {
+      axis = axes[j];
+
+      if (abs(axis) > 0x1000) {
+         /* Subimage extraction by type. */
+         k = abs(axis) & 0xFF;
+
+         longitude = k & WCSSUB_LONGITUDE;
+         latitude  = k & WCSSUB_LATITUDE;
+         cubeface  = k & WCSSUB_CUBEFACE;
+         spectral  = k & WCSSUB_SPECTRAL;
+         stokes    = k & WCSSUB_STOKES;
+
+         if (other = (axis < 0)) {
+            longitude = !longitude;
+            latitude  = !latitude;
+            cubeface  = !cubeface;
+            spectral  = !spectral;
+            stokes    = !stokes;
+         }
+
+         for (i = 0; i < naxis; i++) {
+            strncpy (ctypei, (char *)(wcssrc->ctype + i), 8);
+            ctypei[8] = '\0';
+
+            /* Find the last non-blank character. */
+            c = ctypei + 8;
+            while (c-- > ctypei) {
+               if (*c == ' ') *c = '\0';
+               if (*c != '\0') break;
+            }
+
+            if (
+               strcmp(ctypei,   "RA")  == 0 ||
+               strcmp(ctypei+1, "LON") == 0 ||
+               strcmp(ctypei+2, "LN")  == 0 ||
+               strncmp(ctypei,   "RA---", 5) == 0 ||
+               strncmp(ctypei+1, "LON-", 4) == 0 ||
+               strncmp(ctypei+2, "LN-", 3) == 0) {
+               if (!longitude) {
+                  continue;
+               }
+
+            } else if (
+               strcmp(ctypei,   "DEC") == 0 ||
+               strcmp(ctypei+1, "LAT") == 0 ||
+               strcmp(ctypei+2, "LT")  == 0 ||
+               strncmp(ctypei,   "DEC--", 5) == 0 ||
+               strncmp(ctypei+1, "LAT-", 4) == 0 ||
+               strncmp(ctypei+2, "LT-", 3) == 0) {
+               if (!latitude) {
+                  continue;
+               }
+
+            } else if (strcmp(ctypei, "CUBEFACE") == 0) {
+               if (!cubeface) {
+                  continue;
+               }
+
+            } else if ((
+               strncmp(ctypei, "FREQ", 4) == 0 ||
+               strncmp(ctypei, "ENER", 4) == 0 ||
+               strncmp(ctypei, "WAVN", 4) == 0 ||
+               strncmp(ctypei, "VRAD", 4) == 0 ||
+               strncmp(ctypei, "WAVE", 4) == 0 ||
+               strncmp(ctypei, "VOPT", 4) == 0 ||
+               strncmp(ctypei, "ZOPT", 4) == 0 ||
+               strncmp(ctypei, "AWAV", 4) == 0 ||
+               strncmp(ctypei, "VELO", 4) == 0 ||
+               strncmp(ctypei, "BETA", 4) == 0) &&
+               (ctypei[4] == '\0' || ctypei[4] == '-')) {
+               if (!spectral) {
+                  continue;
+               }
+
+            } else if (strcmp(ctypei, "STOKES") == 0) {
+               if (!stokes) {
+                  continue;
+               }
+
+            } else if (!other) {
+               continue;
+            }
+
+            /* This axis is wanted, but has it already been added? */
+            for (k = 0; k < msub; k++) {
+               if (map[k] == i+1) {
+                  break;
+               }
+            }
+            if (k == msub) map[msub++] = i+1;
+         }
+
+      } else if (0 < axis && axis <= naxis) {
+         /* Check that the requested axis has not already been added. */
+         for (k = 0; k < msub; k++) {
+            if (map[k] == axis) {
+               break;
+            }
+         }
+         if (k == msub) map[msub++] = axis;
+
+      } else {
+         status = 12;
+         goto dealloc;
+      }
+   }
+
+   if ((*nsub = msub) == 0) {
+      status = 0;
+      goto dealloc;
+   }
+
+   for (i = 0; i < *nsub; i++) {
+      axes[i] = map[i];
+   }
+
+
+   /* Construct the inverse axis map. */
+   for (i = 0; i < naxis; i++) {
+      map[i] = 0;
+   }
+
+   for (i = 0; i < *nsub; i++) {
+      map[axes[i]-1] = i+1;
+   }
+
+   /* Check that the subimage coordinate system is separable. */
+   if (*nsub < naxis) {
+      srcp = wcssrc->pc;
+      for (i = 0; i < naxis; i++) {
+         for (j = 0; j < naxis; j++) {
+            if (*(srcp++) == 0.0 || j == i) continue;
+
+            if ((map[i] == 0) != (map[j] == 0)) {
+               status = 13;
+               goto dealloc;
+            }
+         }
+      }
+   }
+
+
+   /* Initialize the destination. */
+   npv = NPVMAX;
+   nps = NPSMAX;
+
+   NPVMAX = 0;
+   for (k = 0; k < wcssrc->npv; k++) {
+      i = wcssrc->pv[k].i;
+      if (i == 0 || (i > 0 && map[i-1])) {
+         NPVMAX++;
+      }
+   }
+
+   NPSMAX = 0;
+   for (k = 0; k < wcssrc->nps; k++) {
+      i = wcssrc->ps[k].i;
+      if (i > 0 && map[i-1]) {
+         NPSMAX++;
+      }
+   }
+
+   status = wcsini(alloc, *nsub, wcsdst);
+
+   NPVMAX = npv;
+   NPSMAX = nps;
+
+   if (status) {
+      goto dealloc;
+   }
+
 
    /* Linear transformation. */
    srcp = wcssrc->crpix;
    dstp = wcsdst->crpix;
-   for (j = 0; j < naxis; j++) {
-      *(dstp++) = *(srcp++);
+   for (j = 0; j < *nsub; j++) {
+      k = axes[j] - 1;
+      *(dstp++) = *(srcp+k);
    }
 
    srcp = wcssrc->pc;
    dstp = wcsdst->pc;
-   for (i = 0; i < naxis; i++) {
-      for (j = 0; j < naxis; j++) {
-         *(dstp++) = *(srcp++);
+   for (i = 0; i < *nsub; i++) {
+      for (j = 0; j < *nsub; j++) {
+         k = (axes[i]-1)*naxis + (axes[j]-1);
+         *(dstp++) = *(srcp+k);
       }
    }
 
    srcp = wcssrc->cdelt;
    dstp = wcsdst->cdelt;
-   for (i = 0; i < naxis; i++) {
-      *(dstp++) = *(srcp++);
+   for (i = 0; i < *nsub; i++) {
+      k = axes[i] - 1;
+      *(dstp++) = *(srcp+k);
    }
 
    /* Coordinate units and type. */
-   for (i = 0; i < naxis; i++) {
-      strncpy(wcsdst->cunit[i], wcssrc->cunit[i], 72);
-      strncpy(wcsdst->ctype[i], wcssrc->ctype[i], 72);
+   for (i = 0; i < *nsub; i++) {
+      k = axes[i] - 1;
+      strncpy(wcsdst->cunit[i], wcssrc->cunit[k], 72);
+      strncpy(wcsdst->ctype[i], wcssrc->ctype[k], 72);
    }
 
    /* Coordinate reference value. */
    srcp = wcssrc->crval;
    dstp = wcsdst->crval;
-   for (i = 0; i < naxis; i++) {
-      *(dstp++) = *(srcp++);
+   for (i = 0; i < *nsub; i++) {
+      k = axes[i] - 1;
+      *(dstp++) = *(srcp+k);
    }
 
    /* Celestial and spectral transformation parameters. */
@@ -559,35 +759,46 @@ struct wcsprm *wcsdst;
    wcsdst->restwav = wcssrc->restwav;
 
    /* Parameter values. */
-   wcsdst->npv = wcssrc->npv;
-   for (k = 0; k < wcssrc->npvmax; k++) {
-     wcsdst->pv[k].i = wcssrc->pv[k].i;
-     wcsdst->pv[k].m = wcssrc->pv[k].m;
-     wcsdst->pv[k].value = wcssrc->pv[k].value;
+   npv = 0;
+   for (k = 0; k < wcssrc->npv; k++) {
+      i = wcssrc->pv[k].i;
+      if (i == 0 || (i > 0 && (i = map[i-1]))) {
+         /* i == 0 is a special code for the latitude axis. */
+         wcsdst->pv[npv] = wcssrc->pv[k];
+         wcsdst->pv[npv].i = i;
+         npv++;
+      }
    }
+   wcsdst->npv = npv;
 
-   wcsdst->nps = wcssrc->nps;
-   for (k = 0; k < wcssrc->npsmax; k++) {
-     wcsdst->ps[k].i = wcssrc->ps[k].i;
-     wcsdst->ps[k].m = wcssrc->ps[k].m;
-     strncpy(wcsdst->ps[k].value, wcssrc->ps[k].value, 72);
+   nps = 0;
+   for (k = 0; k < wcssrc->nps; k++) {
+      i = wcssrc->ps[k].i;
+      if (i > 0 && (i = map[i-1])) {
+         wcsdst->ps[nps] = wcssrc->ps[k];
+         wcsdst->ps[nps].i = i;
+         nps++;
+      }
    }
+   wcsdst->nps = nps;
 
    /* Alternate linear transformations. */
    wcsdst->altlin = wcssrc->altlin;
 
    srcp = wcssrc->cd;
    dstp = wcsdst->cd;
-   for (i = 0; i < naxis; i++) {
-      for (j = 0; j < naxis; j++) {
-         *(dstp++) = *(srcp++);
+   for (i = 0; i < *nsub; i++) {
+      for (j = 0; j < *nsub; j++) {
+         k = (axes[i]-1)*naxis + (axes[j]-1);
+         *(dstp++) = *(srcp+k);
       }
    }
 
    srcp = wcssrc->crota;
    dstp = wcsdst->crota;
-   for (i = 0; i < naxis; i++) {
-      *(dstp++) = *(srcp++);
+   for (i = 0; i < *nsub; i++) {
+      k = axes[i] - 1;
+      *(dstp++) = *(srcp+k);
    }
 
    /* Auxiliary coordinate system information. */
@@ -595,10 +806,11 @@ struct wcsprm *wcsdst;
    wcsdst->colnum = wcssrc->colnum;
 
    strncpy(wcsdst->wcsname, wcssrc->wcsname, 72);
-   for (i = 0; i < naxis; i++) {
-      strncpy(wcsdst->cname[i], wcssrc->cname[i], 72);
-      wcsdst->crder[i] = wcssrc->crder[i];
-      wcsdst->csyer[i] = wcssrc->csyer[i];
+   for (i = 0; i < *nsub; i++) {
+      k = axes[i] - 1;
+      strncpy(wcsdst->cname[i], wcssrc->cname[k], 72);
+      wcsdst->crder[i] = wcssrc->crder[k];
+      wcsdst->csyer[i] = wcssrc->csyer[k];
    }
 
    strncpy(wcsdst->radesys, wcssrc->radesys, 72);
@@ -607,7 +819,7 @@ struct wcsprm *wcsdst;
    strncpy(wcsdst->specsys, wcssrc->specsys, 72);
    strncpy(wcsdst->ssysobs, wcssrc->ssysobs, 72);
    wcsdst->velosys = wcssrc->velosys;
-   wcsdst->vsource = wcssrc->vsource;
+   strncpy(wcsdst->ssyssrc, wcssrc->ssyssrc, 72);
    wcsdst->zsource = wcssrc->zsource;
 
    wcsdst->obsgeo[0] = wcssrc->obsgeo[0];
@@ -618,7 +830,14 @@ struct wcsprm *wcsdst;
    wcsdst->mjdobs = wcssrc->mjdobs;
    wcsdst->mjdavg = wcssrc->mjdavg;
 
-   return 0;
+
+dealloc:
+   if (map) free(map);
+   if (dealloc) {
+     free(axes);
+   }
+
+   return status;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -780,20 +999,24 @@ const struct wcsprm *wcs;
 
    k = 0;
    printf("         cd: 0x%x\n", (int)wcs->cd);
-   for (i = 0; i < wcs->naxis; i++) {
-      printf("    cd[%d][]:", i);
-      for (j = 0; j < wcs->naxis; j++) {
-         printf("  %- 11.4g", wcs->cd[k++]);
+   if (wcs->cd) {
+      for (i = 0; i < wcs->naxis; i++) {
+         printf("    cd[%d][]:", i);
+         for (j = 0; j < wcs->naxis; j++) {
+            printf("  %- 11.4g", wcs->cd[k++]);
+         }
+         printf("\n");
       }
-      printf("\n");
    }
 
    printf("      crota: 0x%x\n", (int)wcs->crota);
-   printf("            ");
-   for (i = 0; i < wcs->naxis; i++) {
-      printf("  %- 11.4g", wcs->crota[i]);
+   if (wcs->crota) {
+      printf("            ");
+      for (i = 0; i < wcs->naxis; i++) {
+         printf("  %- 11.4g", wcs->crota[i]);
+      }
+      printf("\n");
    }
-   printf("\n");
 
    /* Auxiliary coordinate system information. */
    printf("        alt: '%c'\n", wcs->alt[0]);
@@ -806,35 +1029,41 @@ const struct wcsprm *wcs;
    }
 
    printf("      cname: 0x%x\n", (int)wcs->cname);
-   for (i = 0; i < wcs->naxis; i++) {
-      if (wcs->cname[i][0] == '\0') {
-         printf("             UNDEFINED\n");
-      } else {
-         printf("             \"%s\"\n", wcs->cname[i]);
+   if (wcs->cname) {
+      for (i = 0; i < wcs->naxis; i++) {
+         if (wcs->cname[i][0] == '\0') {
+            printf("             UNDEFINED\n");
+         } else {
+            printf("             \"%s\"\n", wcs->cname[i]);
+         }
       }
    }
 
    printf("      crder: 0x%x\n", (int)wcs->crder);
-   printf("           ");
-   for (i = 0; i < wcs->naxis; i++) {
-      if (undefined(wcs->crder[i])) {
-         printf("  UNDEFINED   ");
-      } else {
-         printf("  %- 11.4g", wcs->crder[i]);
+   if (wcs->crder) {
+      printf("           ");
+      for (i = 0; i < wcs->naxis; i++) {
+         if (undefined(wcs->crder[i])) {
+            printf("  UNDEFINED   ");
+         } else {
+            printf("  %- 11.4g", wcs->crder[i]);
+         }
       }
+      printf("\n");
    }
-   printf("\n");
 
    printf("      csyer: 0x%x\n", (int)wcs->csyer);
-   printf("           ");
-   for (i = 0; i < wcs->naxis; i++) {
-      if (undefined(wcs->csyer[i])) {
-         printf("  UNDEFINED   ");
-      } else {
-         printf("  %- 11.4g", wcs->csyer[i]);
+   if (wcs->csyer) {
+      printf("           ");
+      for (i = 0; i < wcs->naxis; i++) {
+         if (undefined(wcs->csyer[i])) {
+            printf("  UNDEFINED   ");
+         } else {
+            printf("  %- 11.4g", wcs->csyer[i]);
+         }
       }
+      printf("\n");
    }
-   printf("\n");
 
    if (wcs->radesys[0] == '\0') {
       printf("    radesys: UNDEFINED\n");
@@ -866,10 +1095,10 @@ const struct wcsprm *wcs;
       printf("    velosys: %9f\n", wcs->velosys);
    }
 
-   if (undefined(wcs->vsource)) {
-      printf("    vsource: UNDEFINED\n");
+   if (wcs->ssyssrc[0] == '\0') {
+      printf("    ssyssrc: UNDEFINED\n");
    } else {
-      printf("    vsource: %9f\n", wcs->vsource);
+      printf("    ssyssrc: \"%s\"\n", wcs->ssyssrc);
    }
 
    if (undefined(wcs->zsource)) {
@@ -878,13 +1107,12 @@ const struct wcsprm *wcs;
       printf("    zsource: %9f\n", wcs->zsource);
    }
 
-   printf("     obsgeo: 0x%x\n", (int)wcs->obsgeo);
-   printf("           ");
+   printf("     obsgeo: ");
    for (i = 0; i < 3; i++) {
       if (undefined(wcs->obsgeo[i])) {
-         printf("  UNDEFINED   ");
+         printf("UNDEFINED     ");
       } else {
-         printf("  %- 11.4g", wcs->obsgeo[i]);
+         printf("%- 11.4g  ", wcs->obsgeo[i]);
       }
    }
    printf("\n");
@@ -1239,20 +1467,23 @@ struct wcsprm *wcs;
 
       } else if (wcs->altlin & 4) {
          /* Construct PCi_ja from CROTAia. */
-         i = wcs->lng;
-         j = wcs->lat;
-         rho = wcs->crota[j];
+         if ((i = wcs->lng) >= 0 && (j = wcs->lat) >= 0) {
+            rho = wcs->crota[j];
 
-         if (wcs->cdelt[i] == 0.0) return 3;
-         lambda = wcs->cdelt[j]/wcs->cdelt[i];
+            if (wcs->cdelt[i] == 0.0) return 3;
+            lambda = wcs->cdelt[j]/wcs->cdelt[i];
 
-         *(pc + i*naxis + i) = *(pc + j*naxis + j) = cosd(rho);
-         *(pc + i*naxis + j) = *(pc + j*naxis + i) = sind(rho);
-         *(pc + i*naxis + j) *= -lambda;
-         *(pc + j*naxis + i) /=  lambda;
+            *(pc + i*naxis + i) = *(pc + j*naxis + j) = cosd(rho);
+            *(pc + i*naxis + j) = *(pc + j*naxis + i) = sind(rho);
+            *(pc + i*naxis + j) *= -lambda;
+            *(pc + j*naxis + i) /=  lambda;
+         }
       }
    }
 
+   wcs->lin.crpix  = wcs->crpix;
+   wcs->lin.pc     = wcs->pc;
+   wcs->lin.cdelt  = wcs->cdelt;
    if (status = linset(&(wcs->lin))) {
       return status;
    }
@@ -1275,7 +1506,7 @@ double world[];
 int stat[];
 
 {
-   int    face, i, iso_x, iso_y, k, nx, ny, *statp, status, statx2s, wcslat,
+   int    face, i, iso_x, iso_y, istat, k, nx, ny, *statp, status, wcslat,
           wcslng, wcspec;
    double offset, *worldlat, *worldlng;
    register double *img, *wrl;
@@ -1379,13 +1610,13 @@ int stat[];
       /* Transform projection plane coordinates to celestial coordinates. */
       worldlng = (double *)world + wcslng;
       worldlat = (double *)world + wcslat;
-      if (statx2s = celx2s(wcscel, nx, ny, nelem, nelem, imgcrd+wcslng,
-                           imgcrd+wcslat, phi, theta, worldlng, worldlat,
-                           stat)) {;
-         if (statx2s == 5) {
+      if (istat = celx2s(wcscel, nx, ny, nelem, nelem, imgcrd+wcslng,
+                         imgcrd+wcslat, phi, theta, worldlng, worldlat,
+                         stat)) {;
+         if (istat == 5) {
             status = 8;
          } else {
-            return statx2s + 3;
+            return istat + 3;
          }
       }
 
@@ -1408,12 +1639,12 @@ int stat[];
          nx = 1;
       }
 
-      if (statx2s = spcx2s(&(wcs->spc), nx, nelem, nelem, imgcrd+wcspec,
-                       world+wcspec, stat)) {
-         if (statx2s == 3) {
+      if (istat = spcx2s(&(wcs->spc), nx, nelem, nelem, imgcrd+wcspec,
+                         world+wcspec, stat)) {
+         if (istat == 3) {
             status = 8;
          } else {
-            return statx2s + 3;
+            return istat + 3;
          }
       }
 
@@ -1440,7 +1671,7 @@ double pixcrd[];
 int stat[];
 
 {
-   int    i, isolat, isolng, isospec, k, nlat, nlng, nspec, status, stats2x,
+   int    i, isolat, isolng, isospec, istat, k, nlat, nlng, nspec, status,
           wcslat, wcslng, wcspec;
    double offset;
    register double *img, *wrl;
@@ -1448,6 +1679,7 @@ int stat[];
 
 
    /* Initialize if required. */
+   status = 0;
    if (wcs == 0) return 1;
    if (wcs->flag != WCSSET) {
       if (status = wcsset(wcs)) return status;
@@ -1492,13 +1724,13 @@ int stat[];
       }
 
       /* Transform celestial coordinates to projection plane coordinates. */
-      if (stats2x = cels2x(wcscel, nlng, nlat, nelem, nelem, world+wcslng,
-                           world+wcslat, phi, theta, imgcrd+wcslng,
-                           imgcrd+wcslat, stat)) {
-         if (stats2x == 6) {
+      if (istat = cels2x(wcscel, nlng, nlat, nelem, nelem, world+wcslng,
+                         world+wcslat, phi, theta, imgcrd+wcslng,
+                         imgcrd+wcslat, stat)) {
+         if (istat == 6) {
             status = 9;
          } else {
-            return stats2x + 3;
+            return istat + 3;
          }
       }
 
@@ -1556,12 +1788,12 @@ int stat[];
          nspec = 1;
       }
 
-      if (stats2x = spcs2x(&(wcs->spc), nspec, nelem, nelem, world+wcspec,
-                       imgcrd+wcspec, stat)) {
-         if (stats2x == 4) {
+      if (istat = spcs2x(&(wcs->spc), nspec, nelem, nelem, world+wcspec,
+                         imgcrd+wcspec, stat)) {
+         if (istat == 4) {
             status = 9;
          } else {
-            return stats2x + 3;
+            return istat + 3;
          }
       }
 
@@ -1574,8 +1806,8 @@ int stat[];
 
 
    /* Apply world-to-pixel linear transformation. */
-   if (status = linx2p(&(wcs->lin), ncoord, nelem, imgcrd, pixcrd)) {
-      return status;
+   if (istat = linx2p(&(wcs->lin), ncoord, nelem, imgcrd, pixcrd)) {
+      return istat;
    }
 
    return status;
