@@ -1,6 +1,6 @@
 *=======================================================================
 *
-*   WCSLIB 3.5 - an implementation of the FITS WCS convention.
+*   WCSLIB 3.6 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2004, Mark Calabretta
 *
 *   This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
 *   http://www.atnf.csiro.au/~mcalabre/index.html
-*   $Id: tprj1.f,v 3.5 2004/06/28 04:51:23 mcalabre Exp $
+*   $Id: tprj1.f,v 3.6 2004/08/25 06:32:04 cal103 Exp $
 *=======================================================================
 
       PROGRAM TPRJ1
@@ -51,7 +51,7 @@
 *#include <f77_floatingpoint.h>
 *      call ieee_handler ('set', 'common', SIGFPE_ABORT)
 
-      WRITE (6, 10)
+      WRITE (*, 10)
  10   FORMAT (/,'Testing closure of WCSLIB spherical projection ',
      :          'routines',/,
      :          '-----------------------------------------------',
@@ -209,7 +209,7 @@
          STATUS = PRJPUT (PRJ, PRJ_PV, PV(J), J)
  10   CONTINUE
 
-      WRITE (6, 20) PCODE, NORTH, SOUTH, TOL
+      WRITE (*, 20) PCODE, NORTH, SOUTH, TOL
  20   FORMAT ('Testing ',A3,'; latitudes',I3,' to',I4,
      :        ', reporting tolerance',1PG8.1,' deg.')
 
@@ -227,15 +227,15 @@
 
          STATUS = PRJS2X (PRJ, 361, 1, 1, 1, LNG1, LAT1, X, Y, STAT1)
          IF (STATUS.EQ.1) THEN
-            WRITE (6, 40) PCODE, STATUS
- 40         FORMAT (3X,A3,'(S2X):  Error',I2)
+            WRITE (*, 40) PCODE, STATUS
+ 40         FORMAT (3X,A3,'(S2X):  ERROR',I2)
             GO TO 80
          END IF
 
          STATUS = PRJX2S (PRJ, 361, 0, 1, 1, X, Y, LNG2, LAT2, STAT2)
          IF (STATUS.EQ.1) THEN
-            WRITE (6, 50) PCODE, STATUS
- 50         FORMAT (3X,A3,'(X2S):  Error',I2)
+            WRITE (*, 50) PCODE, STATUS
+ 50         FORMAT (3X,A3,'(X2S):  ERROR',I2)
             GO TO 80
          END IF
 
@@ -244,10 +244,10 @@
             IF (STAT1(J).NE.0) GO TO 70
 
             IF (STAT2(J).NE.0) THEN
-               WRITE (6, 55) PCODE, LNG1(J), LAT1, X(J), Y(J), STAT2(J)
+               WRITE (*, 55) PCODE, LNG1(J), LAT1, X(J), Y(J), STAT2(J)
  55            FORMAT (3X,A3,'(X2S): lng1 =',F20.15,'  lat1 =',F20.15,/,
      :                 '                x =',F20.15,'     y =',F20.15,
-     :                 '  error',I3)
+     :                 '  ERROR',I3)
                GO TO 70
             END IF
 
@@ -258,21 +258,21 @@
             IF (DLAT.GT.DLATMX) DLATMX = DLAT
 
             IF (DLAT.GT.TOL) THEN
-               WRITE (6, 60) PCODE, LNG1(J), LAT1, X(J), Y(J), LNG2(J),
+               WRITE (*, 60) PCODE, LNG1(J), LAT1, X(J), Y(J), LNG2(J),
      :                       LAT2(J)
  60            FORMAT (8X,A3,': lng1 =',F20.15,'  lat1 =',F20.15,/,
      :                 8X,'        x =',F20.15,'     y =',F20.15,/,
      :                 8X,'     lng2 =',F20.15,'  lat2 =',F20.15)
             ELSE IF (ABS(LAT).NE.90) THEN
                IF (DLNG.GT.TOL) THEN
-                  WRITE (6, 60) PCODE, LNG1(J), LAT1, X(J), Y(J),
+                  WRITE (*, 60) PCODE, LNG1(J), LAT1, X(J), Y(J),
      :                          LNG2(J), LAT2(J)
                END IF
             END IF
  70      CONTINUE
  80   CONTINUE
 
-      WRITE (6, 90) DLNGMX, DLATMX
+      WRITE (*, 90) DLNGMX, DLATMX
  90   FORMAT (13X,'Maximum residual (sky): lng',1P,E10.3,'   lat',E10.3)
 
 
@@ -288,17 +288,17 @@
 
          STATUS = PRJX2S (PRJ, 1, 1, 1, 1, X1, Y1, LNG1, LAT1, STAT2)
          IF (STATUS.NE.0) THEN
-            WRITE (6, 100) PCODE, X1(1), Y1(1), STATUS
+            WRITE (*, 100) PCODE, X1(1), Y1(1), STATUS
  100        FORMAT (8X,A3,'(X2S):   x1 =',F20.15,'    y1 =',F20.15,
-     :              '  error',I3)
+     :              '  ERROR',I3)
             GO TO 130
          END IF
 
          STATUS = PRJS2X (PRJ, 1, 1, 1, 1, LNG1, LAT1, X2, Y2, STAT1)
          IF (STATUS.NE.0) THEN
-            WRITE (6, 110) PCODE, X1(1), Y1(1), LNG1(1), LAT1, STATUS
+            WRITE (*, 110) PCODE, X1(1), Y1(1), LNG1(1), LAT1, STATUS
  110        FORMAT (3X,A3,':   x1 =',F20.15,'    y1 =',F20.15,/,
-     :              3X,'      lng =',F20.15,'   lat =',F20.15,'  error',
+     :              3X,'      lng =',F20.15,'   lat =',F20.15,'  ERROR',
      :              I3)
             GO TO 130
          END IF
@@ -306,7 +306,7 @@
          DR = SQRT((X2(1)-X1(1))**2 + (Y2(1)-Y1(1))**2)
          IF (DR.GT.DRMAX) DRMAX = DR
          IF (DR.GT.TOL) THEN
-            WRITE (6, 120) PCODE, X1(1), Y1(1), LNG1(1), LAT1, X2(1),
+            WRITE (*, 120) PCODE, X1(1), Y1(1), LNG1(1), LAT1, X2(1),
      :                     Y2(1)
  120        FORMAT (8X,A3,':   x1 =',F20.15,'    y1 =',F20.15,/,
      :              8X,'      lng =',F20.15,'   lat =',F20.15,/,
@@ -317,7 +317,7 @@
          THETA = THETA + 15D0
  140  CONTINUE
 
-      WRITE (6, 150) DRMAX
+      WRITE (*, 150) DRMAX
  150  FORMAT (13X,'Maximum residual (ref):  dR',1PE10.3)
 
 
